<?php
/**
 * File to sanitize customizer field
 *
 * @package hotel_melbourne_lite
 * @since 1.0.0
 */

if ( ! function_exists( 'hotel_melbourne_lite_sanitize_checkbox' ) ) :

    /**
     * Sanitize checkbox.
     *
     * @since 1.0.0
     *
     * @param bool $checked Whether the checkbox is checked.
     * @return bool Whether the checkbox is checked.
     */
    function hotel_melbourne_lite_sanitize_checkbox( $checked ) {

        return ( ( isset( $checked ) && true === $checked ) ? true : false );

    }

endif;

if ( ! function_exists( 'hotel_melbourne_lite_sanitize_select' ) ) :

    /**
     * Sanitize select.
     *
     * @since 1.0.0
     *
     * @param mixed                $input The value to sanitize.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return mixed Sanitized value.
     */
    function hotel_melbourne_lite_sanitize_select( $input, $setting ) {

        // Ensure input is a slug.
        $input = sanitize_key( $input );

        // Get list of choices from the control associated with the setting.
        $choices = $setting->manager->get_control( $setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

    }

endif;

if ( ! function_exists( 'hotel_melbourne_lite_sanitize_category' ) ) :
function hotel_melbourne_lite_sanitize_category($input){
    $output=intval($input);
    return $output;
}
endif;


if ( ! function_exists( 'hotel_melbourne_lite_sanitize_dropdown_pages' ) ) :

    function hotel_melbourne_lite_sanitize_dropdown_pages( $page_id, $setting ) {
        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );
        
        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
    }
endif;

if ( ! function_exists( 'hotel_melbourne_lite_sanitize_number_absint' ) ) :

    function hotel_melbourne_lite_sanitize_number_absint( $number, $setting ) {
        // Ensure $number is an absolute integer (whole number, zero or greater).
        $number = absint( $number );
        
        // If the input is an absolute integer, return it; otherwise, return the default
        return ( $number ? $number : $setting->default );
    }
endif;